function area = areaOfRectPizza(length,width)
%areaOfRectPizza compute area of rectangular pizza, given length and width
%
% consumes: 
%     length: number, length of the pizza in inches
%     width:  number, width of the pizza in inches
% produces:
%     area: number, area of the pizza in square inches
%     
% examples
%     >> areaOfPizza(10,12)
%     ans = 120
%     >> areaOfPizza(13,13)
%     ans = 169
%     
% P.Conrad  CISC106 section 99, 09/03/2007
  
  area = -42;
  return;
  
end % function
